/******************************************************************************
* C Include: Configure                                                        *
*                                                                             *
* File:                                                                       *
*    config.h                                                                 *
*                                                                             *
* Description:                                                                *
*    This include file makes sure that certain pre-processor macros are       *
*    defined.                                                                 *
*                                                                             *
* History:                                                                    *
*    Created    : 06-JAN-94 by J. Doggett,                                    *
*       for the Association of Universities for Research in Astronomy, Inc.   *
*          at the Space Telescope Science Institute,                          *
*       to facilitate the accessing of data from the CD-ROM set of the        *
*          Digitized Sky Survey.                                              *
*    Delivered  : 01-MAR-94 by J. Doggett,                                    *
*       GetImage Version 1.0                                                  *
*                                                                             *
*    Updated    : 06-JUL-94 by J. Doggett,                                    *
*       Put in macro for DEC architecture.                                    *
*    Updated    : 18-OCT-94 by J. Doggett,                                    *
*       Put in definition of USE_SSMOUNT macro to govern compiling in the use *
*       of the SS_MOUNT program for disc mounting management.  Also, made     *
*       sure the USE_SSMOUNT is NOT defined for OpenVMS systems.              *
*    Redelivered: 30-NOV-94 by J. Doggett,                                    *
*       GetImage Version 1.1.                                                 *
*                                                                             *
* Copyright (c) 1994, Association of Universities for Research in Astronomy,  *
* Inc.  All Rights Reserved.                                                  *
* Produced under National Aeronautics and Space Administration grant          *
* NAG W-2166.                                                                 *
******************************************************************************/
#ifndef __CONFIG__
#define __CONFIG__

/******************************************************************************
* Leave USE_SSMOUNT defined under Solaris 2.x or if you need a CDROM mounter  *
* for unpriviledged users under Solaris 1.x.  See the file ss_mount.txt for   *
* details on the SS_MOUNT program.                                            *
*                                                                             *
* Comment out the following line defining the USE_SSMOUNT macro if you do NOT *
* wish to use the SS_MOUNT program on UNIX systems to handle disc mounting    *
* management.                                                                 *
******************************************************************************/
#define USE_SSMOUNT

/******************************************************************************
*******************************************************************************
*                                                  ****************************
* NO MODIFICATIONS BELOW THIS POINT ARE NECESSARY. ****************************
*                                                  ****************************
*******************************************************************************
******************************************************************************/

/*********************************************
* Macro's which tell us what system we're on *
*********************************************/
/* OpenVMS. For OpenVMS, the VMS macro or __VMS macro IS pre-defined. */
#ifdef VMS
# ifndef __VMS
#   define __VMS
# endif
#endif


/********************************
* Configure include file page 2 *
********************************/

/* Make sure SS_MOUNT program is not used under OpenVMS */
#if defined __VMS
# ifdef USE_SSMOUNT
#   undef USE_SSMOUNT
# endif
#endif

/* DEC architecture
 * If we're on a VAX, then make sure VAX is defined.  If we're on an ALPHA,
 * then, __ALPHA WILL already be defined.
 */
#if defined VAX
# ifndef __VAX
#  define __VAX
# endif
#else
# ifdef __VAX
#  undef __VAX
# endif
#endif

/* UNIX-like. For now, UNIX-like means not OpenVMS */
#ifndef __VMS
# ifndef __UNIX
#  define __UNIX
# endif
#endif

/****************
* Useful macros *
****************/
#ifndef  EXIT_FAILURE
# define EXIT_FAILURE 1
#endif

#ifndef  EXIT_SUCCESS
# define EXIT_SUCCESS 0
#endif

#ifndef  BLANK
# define BLANK " "
#endif

#ifndef  TRUE
# define TRUE 1
#endif

#ifndef  FALSE
# define FALSE 0

#endif

#endif
